==> haskell-vector-hashtables-0.1.1.4-18-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-vector-hashtables.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 vector-hashtables
version:              0.1.1.4
visibility:           public
id:                   vector-hashtables-0.1.1.4-7wRefVfG8w1CYwYsRiJMxq
key:                  vector-hashtables-0.1.1.4-7wRefVfG8w1CYwYsRiJMxq
license:              BSD-3-Clause
copyright:            2016-2023 klapaucius, swamp_agr
maintainer:           klapaucius, swamp_agr, ArtemPelenitsyn
author:               klapaucius
homepage:             https://github.com/klapaucius/vector-hashtables#readme
synopsis:             Efficient vector-based mutable hashtables implementation.
description:
    This package provides efficient vector-based hashtable implementation similar to .NET Generic Dictionary implementation (at the time of 2015).

    See "Data.Vector.Hashtables" for documentation.

category:             Data
abi:                  de5c36d9483c02d962c02f400cefbb80
exposed:              True
exposed-modules:
    Data.Primitive.PrimArray.Utils Data.Vector.Hashtables
    Data.Vector.Hashtables.Internal
    Data.Vector.Hashtables.Internal.Mask

import-dirs:          /usr/lib/ghc-9.2.8/site-local/vector-hashtables-0.1.1.4
library-dirs:         /usr/lib/ghc-9.2.8/site-local/vector-hashtables-0.1.1.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-vector-hashtables
hs-libraries:         HSvector-hashtables-0.1.1.4-7wRefVfG8w1CYwYsRiJMxq
depends:
    base-4.16.4.0 hashable-1.4.3.0-BWGpbAVaWdFEBuRI2sTyFL
    primitive-0.7.4.0-A9DQl7IN10ADdryf8HN1sF
    vector-0.13.1.0-FqETZo7rR6n5zX4PwJIjNh

haddock-interfaces:
    /usr/share/doc/haskell-vector-hashtables/html/vector-hashtables.haddock

haddock-html:         /usr/share/doc/haskell-vector-hashtables/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-vector-hashtables-0.1.2.0-8-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-vector-hashtables.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 vector-hashtables
version:              0.1.2.0
visibility:           public
id:                   vector-hashtables-0.1.2.0-XMynIsRtBq50TM9EloRxJ
key:                  vector-hashtables-0.1.2.0-XMynIsRtBq50TM9EloRxJ
license:              BSD-3-Clause
copyright:            2016-2024 klapaucius, swamp_agr
maintainer:           klapaucius, swamp_agr, ArtemPelenitsyn
author:               klapaucius
homepage:             https://github.com/klapaucius/vector-hashtables#readme
synopsis:             Efficient vector-based mutable hashtables implementation.
description:
    This package provides efficient vector-based hashtable implementation similar to .NET Generic Dictionary implementation (at the time of 2015).

    See "Data.Vector.Hashtables" for documentation.

category:             Data
abi:                  6a4b1cfa27f5bac0ab305ef205d088d9
exposed:              True
exposed-modules:
    Data.Primitive.PrimArray.Utils Data.Vector.Hashtables
    Data.Vector.Hashtables.Internal
    Data.Vector.Hashtables.Internal.Mask

import-dirs:          /usr/lib/ghc-9.2.8/site-local/vector-hashtables-0.1.2.0
library-dirs:         /usr/lib/ghc-9.2.8/site-local/vector-hashtables-0.1.2.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-vector-hashtables
hs-libraries:         HSvector-hashtables-0.1.2.0-XMynIsRtBq50TM9EloRxJ
depends:
    base-4.16.4.0 hashable-1.4.4.0-KJ184tiZpE52U0PEHxyV1r
    primitive-0.7.4.0-AQ7cOoBXu5aBgAQTQzTLUx
    vector-0.13.1.0-xP3uH1g3cPFld8g0jCD5r

haddock-interfaces:
    /usr/share/doc/haskell-vector-hashtables/html/vector-hashtables.haddock

haddock-html:         /usr/share/doc/haskell-vector-hashtables/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
